/**
 * \file peakscorer.cpp
 *
 * \authors Rowan Zellers
 *
 * \brief Implements the peakscorer class.
 */

#include "peakscorer.hpp"
#include <string>
#include <cstddef>
#include <iostream>
#include <fstream>
#include <vector>
#include <map>
#include <cmath>
#include <cstdlib>
#include <ctime>

using namespace std;

PeakScorer::PeakScorer(const size_t numpeaks,  const size_t numscrambles)
  : numpeaks_(numpeaks), numscrambles_(numscrambles)
{
    // Resize the vectors to the proper length.
    legitscores_.resize(numpeaks);
    scrambledscores_.resize(numpeaks);
    for (size_t i = 0; i < numpeaks; ++i) {
        scrambledscores_[i].resize(numscrambles);
    }
}

void PeakScorer::score(const WeightMatrix& matrix, PeakLoader& peaks,
                const size_t peakID, const size_t scrambleID)
{
    // Pass to the matrix the vector of scores by reference, and it will do
    // all the work for us!
    if (scrambleID == 0) {
        matrix.slideWindow(peaks.getPeak(peakID, scrambleID),
                           legitscores_[peakID], peakID);
    } else {
        matrix.slideWindow(peaks.getPeak(peakID, scrambleID),
                           scrambledscores_[peakID][scrambleID - 1],
                           peakID);
    }
}

std::vector<double>& PeakScorer::getScores(const size_t peakID,
                                   const size_t scrambleID)
{
    if (scrambleID == 0) {
        return legitscores_[peakID];
    } else {
        return scrambledscores_[peakID][scrambleID-1];
    }
}

size_t PeakScorer::getLength(const size_t peakID) const
{
    return legitscores_[peakID].size();
}
