/**
 * \file resultsprinter.cpp
 *
 * \authors Rowan Zellers
 *
 * \brief Contains a function that prints everything out.
 */

#include "resultsmaker.hpp"
#include "freqmatrix.hpp"
#include <string>
#include <ostream>
#include <istream>
#include <vector>
#include "results.hpp"
using namespace std;

/**
 * \brief Prints out results for all the matrices. The first trial that
 *        is printed out is at begin, and the last trial that is printed
 *        out has an ID of end - 1. (So, to print out all trials),
 *        begin = 0 and end = numtrials. Saves to filename filename.
 */
void ResultsPrinter(const size_t matrixid, ResultsMaker& peaks,
    const std::string& filename)
{

    // If the file exists before we made it, don't output the names
    // of the columns.
    bool exists = false;
    ifstream ifile(filename.c_str());
    if (ifile) {
        exists=true;
    }

    ofstream myfile(filename.c_str());
    if (!myfile.is_open()) {
        return;
    }

    if (!exists) {
        myfile << "Type\tTypeName\tThreshold\tScore\t"
               << "Hits\tBorderlines\t"
               << "FalsePositives\tFalse Negatives" << endl;
    }

    FreqMatrix exmatrix(matrixid);

    myfile << matrixid << "\t"
           << exmatrix.strType() << "\t"
           << peaks.fetchResults().threshold_ << "\t"
           << peaks.fetchResults().score_ << "\t"
           << peaks.fetchResults().hits_ << "\t"
           << peaks.fetchResults().epsilons_ << "\t"
           << peaks.fetchResults().unroundedfalsepositives_ << "\t"
           << peaks.fetchResults().falsenegatives_ << endl;

}


